Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5158)

Unified Diff: chrome/browser/chromeos/file_system_provider/operations/close_file.h

Issue 442383002: Move storage-related files from webkit/ to new top-level directory storage/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/file_system_provider/operations/close_file.h
diff --git a/chrome/browser/chromeos/file_system_provider/operations/close_file.h b/chrome/browser/chromeos/file_system_provider/operations/close_file.h
index 83bafff2f5ef3a5af85008ff6fb3fca78a3a030e..5e41837cc89b55bc0a5c209fd4efd8c09a34f924 100644
--- a/chrome/browser/chromeos/file_system_provider/operations/close_file.h
+++ b/chrome/browser/chromeos/file_system_provider/operations/close_file.h
@@ -11,7 +11,7 @@
#include "chrome/browser/chromeos/file_system_provider/provided_file_system_info.h"
#include "chrome/browser/chromeos/file_system_provider/provided_file_system_interface.h"
#include "chrome/browser/chromeos/file_system_provider/request_value.h"
-#include "webkit/browser/fileapi/async_file_util.h"
+#include "storage/browser/fileapi/async_file_util.h"
namespace base {
class FilePath;
@@ -26,14 +26,14 @@ namespace file_system_provider {
namespace operations {
// Opens a file for either read or write, with optionally creating the file
// first. Note, that this is part of fileapi::CreateOrOpen file, but it does
// not download the file locally. Created per request.
class CloseFile : public Operation {
public:
CloseFile(extensions::EventRouter* event_router,
const ProvidedFileSystemInfo& file_system_info,
int open_request_id,
- const fileapi::AsyncFileUtil::StatusCallback& callback);
+ const storage::AsyncFileUtil::StatusCallback& callback);
virtual ~CloseFile();
// Operation overrides.
@@ -47,7 +47,7 @@ class CloseFile : public Operation {
private:
int open_request_id_;
- const fileapi::AsyncFileUtil::StatusCallback callback_;
+ const storage::AsyncFileUtil::StatusCallback callback_;
DISALLOW_COPY_AND_ASSIGN(CloseFile);
};
@@ -26,14 +26,14 @@ namespace file_system_provider {
namespace operations {
// Opens a file for either read or write, with optionally creating the file
-// first. Note, that this is part of fileapi::CreateOrOpen file, but it does
+// first. Note, that this is part of storage::CreateOrOpen file, but it does
// not download the file locally. Created per request.
class CloseFile : public Operation {

Powered by Google App Engine
This is Rietveld 408576698